km3pipe\.dataclasses\.McTrackSeries
===================================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: McTrackSeries

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~McTrackSeries.__init__
      ~McTrackSeries.conv_from
      ~McTrackSeries.conv_to
      ~McTrackSeries.deserialise
      ~McTrackSeries.from_aanet
      ~McTrackSeries.from_arrays
      ~McTrackSeries.from_km3df
      ~McTrackSeries.from_table
      ~McTrackSeries.get_len
      ~McTrackSeries.get_usr_item
      ~McTrackSeries.get_usr_name
      ~McTrackSeries.next
      ~McTrackSeries.serialise
   
   

   
   
   